@@ -9,7 +9,7 @@ export PATH="$HOME/.cargo/bin:$PATH"
 cd /io
 
 for PYBIN in /opt/python/cp{35,36,37,38,39}*/bin; do
-    "${PYBIN}/pip" install -U setuptools wheel setuptools-rust
+    "${PYBIN}/pip" install -U setuptools wheel "setuptools-rust<1.3.0"
     "${PYBIN}/python" setup.py bdist_wheel
 done
 
