@@ -1,4 +1,5 @@
 //! Python extension, exported functions and type conversions.
+#![allow(clippy::borrow_deref_ref)]
 
 pub mod conversions;
 pub mod utils;
@@ -53,7 +54,8 @@ fn pconvert_rust(_py: Python, module: &PyModule) -> PyResult<()> {
         .collect();
     module.add("COMPRESSION_TYPES", compressions)?;
 
-    #[pyfn(module, "blend_images")]
+    #[pyfunction]
+    #[pyo3(name = "blend_images")]
     fn blend_images_py(
         py: Python,
         bot_path: String,
@@ -92,7 +94,8 @@ fn pconvert_rust(_py: Python, module: &PyModule) -> PyResult<()> {
         })
     }
 
-    #[pyfn(module, "blend_multiple")]
+    #[pyfunction]
+    #[pyo3(name = "blend_multiple")]
     fn blend_multiple_py(
         py: Python,
         img_paths: &PySequence,
@@ -107,13 +110,10 @@ fn pconvert_rust(_py: Python, module: &PyModule) -> PyResult<()> {
         let num_images = img_paths.len();
 
         let algorithms_to_apply: Vec<(BlendAlgorithm, Option<BlendAlgorithmParams>)> =
-            if let Some(algorithms) = algorithms {
-                build_params(algorithms)?
-            } else if let Some(algorithm) = algorithm {
-                let algorithm = build_algorithm(&algorithm)?;
-                vec![(algorithm, None); num_images - 1]
-            } else {
-                vec![(BlendAlgorithm::Multiplicative, None); num_images - 1]
+            match (algorithms, algorithm) {
+                (Some(algorithms), _) if algorithms.len().unwrap() > 0 => build_params(algorithms)?,
+                (_, Some(algorithm)) => vec![(build_algorithm(&algorithm)?, None); num_images - 1],
+                _ => vec![(BlendAlgorithm::Multiplicative, None); num_images - 1],
             };
 
         // blends multiple images using either the single-threaded or the multiple-threaded version
@@ -143,7 +143,8 @@ fn pconvert_rust(_py: Python, module: &PyModule) -> PyResult<()> {
         })
     }
 
-    #[pyfn(module, "get_thread_pool_status")]
+    #[pyfunction]
+    #[pyo3(name = "get_thread_pool_status")]
     fn get_thread_pool_status(py: Python) -> PyResult<&PyDict> {
         unsafe {
             match &mut THREAD_POOL {
@@ -152,12 +153,16 @@ fn pconvert_rust(_py: Python, module: &PyModule) -> PyResult<()> {
                     Ok(status_dict)
                 }
                 None => Err(PyException::new_err(
-                    "Acessing global thread pool".to_string(),
+                    "Accessing global thread pool".to_string(),
                 )),
             }
         }
     }
 
+    module.add_function(wrap_pyfunction!(blend_images_py, module)?)?;
+    module.add_function(wrap_pyfunction!(blend_multiple_py, module)?)?;
+    module.add_function(wrap_pyfunction!(get_thread_pool_status, module)?)?;
+
     Ok(())
 }
 
@@ -169,7 +174,7 @@ fn blend_images_single_thread(
     is_inline: Option<bool>,
     options: Option<Options>,
 ) -> PyResult<()> {
-    let algorithm = algorithm.unwrap_or(String::from("multiplicative"));
+    let algorithm = algorithm.unwrap_or_else(|| String::from("multiplicative"));
     let algorithm = build_algorithm(&algorithm)?;
 
     let _is_inline = is_inline.unwrap_or(false);
@@ -198,7 +203,7 @@ unsafe fn blend_images_multi_thread(
     options: Option<Options>,
     num_threads: i32,
 ) -> PyResult<()> {
-    let algorithm = algorithm.unwrap_or(String::from("multiplicative"));
+    let algorithm = algorithm.unwrap_or_else(|| String::from("multiplicative"));
     let algorithm = build_algorithm(&algorithm)?;
     let _is_inline = is_inline.unwrap_or(false);
     let demultiply = is_algorithm_multiplied(&algorithm);
@@ -261,14 +266,18 @@ fn blend_multiple_single_thread(
     // current composition with the next layer
     let mut img_paths_iter = img_paths.iter();
     let first_path = img_paths_iter.next().unwrap().to_string();
-    let first_demultiply = is_algorithm_multiplied(&algorithms[0].0);
+    let first_demultiply = if !algorithms.is_empty() {
+        is_algorithm_multiplied(&algorithms[0].0)
+    } else {
+        false
+    };
     let mut composition = read_png_from_file(first_path, first_demultiply)?;
-    let mut zip_iter = img_paths_iter.zip(algorithms.iter());
-    while let Some(pair) = zip_iter.next() {
+    let zip_iter = img_paths_iter.zip(algorithms.iter());
+    for pair in zip_iter {
         let path = pair.0.to_string();
         let (algorithm, algorithm_params) = pair.1;
-        let demultiply = is_algorithm_multiplied(&algorithm);
-        let algorithm_fn = get_blending_algorithm(&algorithm);
+        let demultiply = is_algorithm_multiplied(algorithm);
+        let algorithm_fn = get_blending_algorithm(algorithm);
         let current_layer = read_png_from_file(path, demultiply)?;
         blend_images(
             &mut composition,
@@ -326,7 +335,12 @@ unsafe fn blend_multiple_multi_thread(
         png_channels.push(result_channel);
     }
 
-    let first_demultiply = is_algorithm_multiplied(&algorithms[0].0);
+    let first_demultiply = if !algorithms.is_empty() {
+        is_algorithm_multiplied(&algorithms[0].0)
+    } else {
+        false
+    };
+
     let mut composition = match png_channels[0].recv().unwrap() {
         ResultMessage::ImageResult(result) => result,
     }?;
@@ -339,8 +353,8 @@ unsafe fn blend_multiple_multi_thread(
     // retrieves the images from the result channels
     for i in 1..png_channels.len() {
         let (algorithm, algorithm_params) = &algorithms[i - 1];
-        let demultiply = is_algorithm_multiplied(&algorithm);
-        let algorithm_fn = get_blending_algorithm(&algorithm);
+        let demultiply = is_algorithm_multiplied(algorithm);
+        let algorithm_fn = get_blending_algorithm(algorithm);
         let mut current_layer = match png_channels[i].recv().unwrap() {
             ResultMessage::ImageResult(result) => result,
         }?;
